#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 crypton-x509-validation
version:              1.6.14
visibility:           public
id:                   crypton-x509-validation-1.6.14-J79YXDmvMfKHIgACxNU3Ym
key:                  crypton-x509-validation-1.6.14-J79YXDmvMfKHIgACxNU3Ym
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             https://github.com/kazu-yamamoto/crypton-certificate
synopsis:             X.509 Certificate and CRL validation
description:          X.509 Certificate and CRL validation. please see README
category:             Data
abi:                  569e3cab7a431e4a1023e3d847315d18
exposed:              True
exposed-modules:      Data.X509.Validation
hidden-modules:
    Data.X509.Validation.Signature Data.X509.Validation.Fingerprint
    Data.X509.Validation.Cache Data.X509.Validation.Types

import-dirs:
    /usr/lib/ghc-9.6.6/site-local/crypton-x509-validation-1.6.14

library-dirs:
    /usr/lib/ghc-9.6.6/site-local/crypton-x509-validation-1.6.14

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/crypton-x509-validation-1.6.14

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-crypton-x509-validation
hs-libraries:         HScrypton-x509-validation-1.6.14-J79YXDmvMfKHIgACxNU3Ym
depends:
    asn1-encoding-0.9.6-K1wE6DLVXnI2IVKbFYSj3P
    asn1-types-0.3.4-8qoa2UhcHlVIz3c3pCwawz base-4.18.2.1
    bytestring-0.11.5.3 containers-0.6.7
    crypton-1.0.4-AWd8bTcUYpP9FBNCextboX
    crypton-x509-1.7.7-Eoy0lsTG0q62AKERj4NmbT
    crypton-x509-store-1.6.12-mz1BFFYRNB88wOcruU0Tw
    data-default-0.7.1.3-EtVHsfbH5oIpJ9umzYHUz
    hourglass-0.2.12-DnUw328VgdNHoTUgZp8vhs
    iproute-1.7.15-2dk95dxlDe053IZw8rubZW
    memory-0.18.0-6zo36PbRecTK4fqbBnx0f5 mtl-2.3.1
    pem-0.2.4-Hc7OzdOfNbTlwvr7D4cbg

haddock-interfaces:
    /usr/share/doc/haskell-crypton-x509-validation/html/crypton-x509-validation.haddock

haddock-html:         /usr/share/doc/haskell-crypton-x509-validation/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

